==> elisa-plugins-bad_0.5.9-1.orig.tar.gz: elisa-plugins-bad-0.5.9/elisa/plugins/daap/setup.py <==
# -*- coding: utf-8 -*-
# Elisa - Home multimedia server
# Copyright (C) 2006-2008 Fluendo Embedded S.L. (www.fluendo.com).
# All rights reserved.
#
# This file is available under one of two license agreements.
#
# This file is licensed under the GPL version 3.
# See "LICENSE.GPL" in the root of this distribution including a special
# exception to use Elisa with Fluendo's plugins.
#
# The GPL part of Elisa is also available under a commercial licensing
# agreement from Fluendo.
# See "LICENSE.Elisa" in the root directory of this distribution package
# for details on that license.
#
# Authors:
#   Benjamin Kampmann <benjamin@fluendo.com>

import os
from setuptools import setup
from elisa.core.utils.dist import find_packages, TrialTest, Clean

packages, package_dir = find_packages(os.path.dirname(__file__))
cmdclass = dict(test=TrialTest, clean=Clean)

setup(name='elisa-plugin-daap',
    version='0.0.1', 
    description='Access DAAP Shares',
    license='GPL3', 
    author='Elisa Developers',
    author_email='elisa@list.fluendo.com',
    namespace_packages=['elisa', 'elisa.plugins'],
    packages=packages,
    package_dir=package_dir,
    controller_mappings=[('/poblesec/music/daap',
                          'elisa.plugins.daap.controller:ArtistsDaapListSwitcherController'),
                         ('/poblesec/music/daap/albums',
                          'elisa.plugins.daap.controller:AlbumsDaapListSwitcherController'),
                         ('/poblesec/music/daap/tracks',
                          'elisa.plugins.daap.controller:TracksDaapListSwitcherController'),],
    cmdclass=cmdclass)

==> elisa-plugins-bad_0.5.28.orig.tar.gz: elisa-plugins-bad-0.5.28/elisa/plugins/daap/setup.py <==
# -*- coding: utf-8 -*-
# Elisa - Home multimedia server
# Copyright (C) 2006-2008 Fluendo Embedded S.L. (www.fluendo.com).
# All rights reserved.
#
# This file is available under one of two license agreements.
#
# This file is licensed under the GPL version 3.
# See "LICENSE.GPL" in the root of this distribution including a special
# exception to use Elisa with Fluendo's plugins.
#
# The GPL part of Elisa is also available under a commercial licensing
# agreement from Fluendo.
# See "LICENSE.Elisa" in the root directory of this distribution package
# for details on that license.
#
# Authors:
#   Benjamin Kampmann <benjamin@fluendo.com>

import os
from setuptools import setup
from elisa.core.utils.dist import find_packages, TrialTest, Clean

packages, package_dir = find_packages(os.path.dirname(__file__))
cmdclass = dict(test=TrialTest, clean=Clean)

setup(name='elisa-plugin-daap',
    version='0.0.1', 
    description='Access DAAP Shares',
    license='GPL3', 
    author='Elisa Developers',
    author_email='elisa@list.fluendo.com',
    namespace_packages=['elisa', 'elisa.plugins'],
    packages=packages,
    package_dir=package_dir,
    controller_mappings=[('/poblesec/music/daap',
                          'elisa.plugins.daap.controller:ArtistsDaapListSwitcherController'),
                         ('/poblesec/music/daap/albums',
                          'elisa.plugins.daap.controller:AlbumsDaapListSwitcherController'),
                         ('/poblesec/music/daap/tracks',
                          'elisa.plugins.daap.controller:TracksDaapListSwitcherController'),],
    cmdclass=cmdclass,
    entry_points="""
    [elisa.core.components.resource_provider]
    DaapResourceProvider = elisa.plugins.daap.daap_resource_provider:DaapResourceProvider
    """)
